@@ -7,6 +7,8 @@ Functions for reading auxiliary data
 .. autosummary::
     :toctree: generated/
 
+    read_centroids_npz
+    read_centroids
     read_proc_periods
     read_profile_ts
     read_histogram_ts
@@ -52,6 +54,73 @@ from pyart.config import get_fillvalue, get_metadata
 from .io_aux import get_fieldname_pyart, _get_datetime
 
 
+def read_centroids_npz(fname):
+    """
+    Reads an npz file containing data used in centroid computation
+
+    Parameters
+    ----------
+    fname : str
+        name of the file to read
+
+    Returns
+    -------
+    centroids_data : dict
+        Dictionary with the data
+
+    """
+    try:
+        with np.load(fname, allow_pickle=True) as npzfile:
+            return npzfile['centroids_data'].item()
+    except EnvironmentError as ee:
+        warn(str(ee))
+        warn('Unable to read file '+fname)
+        return None
+
+
+def read_centroids(fname):
+    """
+    Reads a file containing the centroids for the semi-supervised
+    classification
+
+    Parameters
+    ----------
+    fname : str
+        name of the file to read
+
+    Returns
+    -------
+    mass_centers : 2D-array
+        Matrix with the centroids as (nclasses, nvariables)
+
+    """
+    try:
+        with open(fname, 'r', newline='') as csvfile:
+            # first count the lines
+            reader = csv.DictReader(
+                row for row in csvfile if not row.startswith('#'))
+            nhydro = sum(1 for row in reader)
+            nvars = len(reader.fieldnames)-1
+            mass_centers = np.empty((nhydro, nvars))
+            hydro_names = []
+            var_names = reader.fieldnames[1:]
+
+            # now read the data
+            csvfile.seek(0)
+            reader = csv.DictReader(
+                row for row in csvfile if not row.startswith('#'))
+            for i, row in enumerate(reader):
+                hydro_names.append(row[reader.fieldnames[0]])
+                for j, col in enumerate(var_names):
+                    mass_centers[i, j] = float(row[col])
+
+            return mass_centers, hydro_names, var_names
+    except EnvironmentError as ee:
+        warn(str(ee))
+        warn('Unable to read file '+fname)
+        return None, None, None
+
+
 def read_proc_periods(fname):
     """
     Reads a file containing the start and stop times of periods to process
@@ -386,7 +455,7 @@ def read_status(voltime, cfg, ind_rad=0):
     dayinfo = voltime.strftime('%y%j')
     timeinfo = voltime.strftime('%H%M')
     basename = 'ST'+cfg['RadarName'][ind_rad]+dayinfo
-    if cfg['path_convention'] == 'RT':
+    if cfg['path_convention'][ind_rad] == 'RT':
         datapath = cfg['datapath'][ind_rad]+'ST'+cfg['RadarName'][ind_rad]+'/'
     else:
         datapath = cfg['datapath'][ind_rad]+dayinfo+'/'+basename+'/'
@@ -597,6 +666,7 @@ def read_quantiles(fname):
         warn('Unable to read file '+fname)
         return None, None
 
+
 def read_excess_gates(fname):
     """
     Reads a csv files containing the position of gates exceeding
@@ -1461,7 +1531,8 @@ def read_selfconsistency(fname):
 
     """
     try:
-        with open(fname, 'r', newline='', encoding='utf-8', errors='ignore') as csvfile:
+        with open(fname, 'r', newline='', encoding='utf-8',
+                  errors='ignore') as csvfile:
             # first count the lines
             reader = csv.DictReader(
                 csvfile, fieldnames=['zdr', 'kdpzh'], dialect='excel-tab')
